@@ -108,6 +108,15 @@ class VltiFacility(Facility):
             # TODO we should test much more because lot of stuff still are beeing processed on live ob creations
 
             instrument.checkOB(ob)
+            # check for warnings and abort if requested by user
+            if len(instrument.warnings)>0:
+                linesep="\n  -  "
+                version=instrument.getDitTable()["VERSION"]
+                answer = self.ui.AskYesNoMessage(f"According to the template manual {version} :\n \n  -  {linesep.join(instrument.warnings)}\n\nClick \"Yes\" to proceed \"No\" to abort the submission")
+                instrument.warnings.clear()
+                if answer == False:
+                    self.ui.addToLog("Submission has been marked to be aborted - do not proceed")
+                    return
 
             insname = instrument.getShortName()
 
@@ -124,12 +133,8 @@ class VltiFacility(Facility):
             elif  period != int(self.containerInfo.getIpVersion()):
                 self.ui.ShowErrorMessage(f"Aborting: container's IpVersion '{self.containerInfo.getIpVersion()}' in not applicable for received OB's one '{period}', please change it in Aspro2.")
             else:
-                self.ui.addToLog(
-                    "Everything ready! Request OB creation inside selected container ")
+                ui.addToLog("Everything ready! Request OB creation inside selected container")
                 instrument.submitOB(ob, self.containerInfo)
-                self.ui.addToLog(
-                    "OB submitted! Please check logs and fix last details on P2 web.")
-
 
 
         # TODO add P2Error handling P2Error(r.status_code, method, url,
